// import React from 'react';
// import ReactDOM from 'react-dom';
import d3 from 'd3';

// const App = () => <div className="message">Hello React!</div>;

// ReactDOM.render(<App />, document.getElementById('root'));

let margin = {top: 10, right: 30, bottom: 30, left: 40};
let width = 960 - margin.left - margin.right;
let height = 500 - margin.bottom - margin.top;

// Initialize date/time parser
var parseDate = d3.timeParse("%d-%m-%Y");

// Set the ranges
var x = d3.scaleTime()
	.domain([new Date(2010, 6, 3), new Date(2012, 0, 1)])
	.rangeRound([0, width]);

var y = d3.scaleLinear()
	.range([height, 0]);

// set the parameters for the histogram
var histogram = d3.histogram()
	.value((d) => d.date)
	.domain(x.domain())
	.thresholds(x.ticks(d3.timeMonth));

// append the svg object to the body of the page
// append a 'group' element to 'svg'
// moves the 'group' element to the top left margin
var svg = d3.select("body").append("svg")
	.attr("width", width + margin.left + margin.right)
	.attr("height", height + margin.bottom + margin.top)
.append("g")
	.attr("transform", `translate(${margin.left}, ${margin.top})`);

// get the data
d3.csv("https://bl.ocks.org/d3noob/raw/96b74d0bd6d11427dd797892551a103c/earthquakes.csv", (error, data) => {
	if(error) throw error;
  
  // format the data
  data.forEach((d) => {
  	d.date = parseDate(d.dtg);
  });
  
  // group the data for the bars
  var bins = histogram(data);
  
  // scale the range of the data in the y domain
  y.domain([0, d3.max(bins, (d) => d.length)]);
  
  // append the bar rectangles to the svg element
  svg.selectAll("rect")
  	.data(bins)
  .enter().append("rect")
  	.attr("class", "bar")
  	.attr("x", 1)
  	.aatr("transform", () => {
  		`translate(${x(d.x0)}, ${y(d.length)})`
  	})
  	.attr("width", (d) => x(d.x2) - x(d.x0) - 1)
  	.attr("height", (d) => height - y(d.length));
  
  //add the x Axis
  svg.append("g")
  	.attr("transform", `translate(0, ${height})`)
  	.call(d3.axisBottom(x));
  
  // add the y Axis
  svg.append("g")
  	.call(d3.axisLeft(y));
});
